% List of exceptions created by Karel Horak
% (Mathamatical Institute of Czechoslovak Acadamy of Science)
% Prague, April 1, 1991
%
\hyphenation{
  koe-fi-ci-ent
  koe-fi-ci-en-ty
  pro-jek-ční
  úhlo-příč-ka
  úhlo-příč-ky
}

%%% Local Variables:
%%% mode: tex
%%% coding: latin-2
%%% End:
