% This is the groff hyphenation pattern file `hyphen.cs' for Czech.
%
% It is based on the TeX pattern file `czhyphen.tex', version 3 (1995),
% prepared by Pavel ©eveèek <pavel@lingea.cz>.
%
% Here is the copyright message:
%
%   This is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
%
%   This file is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
%
% Please check the original file for more details.
%
% It has been made suitable for groff by expanding all macros to real
% characters in latin-2 encoding.
%
\patterns{
.a2
.a4da
.a4de
.a4di
.a4do
.a4dé
.a4kl
.a4ko
.a4kr
.a4ku
.ale3x
.a4ra
.a4re
.a4ri
.a4ro
.a4ry
.a4rá
.a4sa
.a4se
.a4so
.as3t3
.a4sy
.a4ta
.a4te
.at3l
.a4to
.a4tr
.a4ty
.a4ve
.b2
.c2
.ch2
.cyk3
.d2
.dez3
.d4na
.dne4
.dne¹4k
.d4ny
.dos4
.d4ve
.d4vì
.d4ví
.e2
.e4ch
.e4ko
.es3k
.es3t
.e4ve
.f4ri
.g2
.h2
.h4le
.h4ne
.i2
.i4na
.i4ni
.i4no
.is3l
.j2
.j4ak
.je4dl
.j4se
.j4zd
.jád4
.k2
.k4li
.k4ly
.køí3d
.l2
.le4gr
.li3kv
.m2
.mi3st4
.moud3
.na3è4
.ne3c
.neè4
.ne3¹
.ni2t
.no4s3t
.n4vp
.ná1
.náø4k
.o2
.o4bé
.ode3
.od3l
.od3rá
.o4ka
.o4ko
.o4na
.o4ne
.o4ni
.o4no
.o4nu
.o4ny
.o4nì
.o4ní
.o4pe
.o4po
.o4se
.o4sl
.os4to
.os3t3r
.os4tì
.ot3rá
.ot3v
.o4tí
.o4tø
.ovì4t
.o4za
.oz3do
.o4zi
.o4zo
.o4zu
.o4¹k
.o4¹l
.o4¾i
.p2
.pa4re
.pa3tø
.polk4l
.po3è4
.p4ro
.p4rý
.p4se
.pu3b
.r2
.rej4
.re3s
.ro4k
.roze3
.roz3r
.ru4dl
.s2
.s4ch
.s4ci
.sem4
.se3pn
.s4ke
.sk4l
.s4ká
.s4le
.s4na
.s4ny
.s4pe
.s4po
.st2
.s4tá
.s4¾i
.t2
.u2
.u4ba
.u4be
.u4bi
.u4bo
.u4de
.u4di
.u4do
.u4du
.u4dí
.uh4n
.uj4m
.u4ko
.u4ku
.ul4h
.u4ma
.u4me
.u4mi
.u4mu
.u4ne
.u4ni
.u4pa
.u4pe
.u4pi
.up4n
.u4po
.u4pu
.u4pá
.u4pì
.u4pí
.u4ra
.u4ro
.u4rá
.us2
.u4so
.u4st
.u4sy
.u4sí
.ut2
.u4vi
.u4ze
.u4èe
.u4èi
.u4èí
.u4¹e
.u4¹i
.u4¹k
.u¹4t
.u4¹í
.u4¾i
.u¾4n
.u4¾o
.u4¾í
.v2
.va4dl
.v4po
.vy3
.v4zá
.vý1
.v4¾i
.y4or
.y4ve
.z2
.za3
.zao3s
.zar2
.zaè2
.zd2
.z4di
.z4dr
.z4ky
.z4mn
.z4no
.z4nu
.z4nì
.z4ní
.z4pe
.z4po
.z4tø
.z4ve
.z4vi
.è2
.è4te
.é2
.í2
.ó2
.¹2
.¹e3t
.¹4ka
.¹4ke
.¹4ky
.¹4»o
.¹4»á
.ú2
.ú4dù
.¾2
a1
2a.
aa3t2
ab3lon
ab4lý
ab3ri
ab4sb
ab2st
ac4ci
a2d
a3da
a3de
a3di
ad2la
a4dli
a4dlá
a4dlé
ad4me
ad4mu
a3do
ado4s
a3d3ra
ad3ri
a3dr¾
a3du
a4du¾
3a3dva
ad3vo
a3dy
a3dá
a3dé
a3dì
a3dí
ad4úz
ad4úø
a3dù
a3dý
ae4vi
afi2a
a2g
a3ga
ag4fa
a3go
ag3ro
a3gu
a3gá
ah4li
ah3v
a2i
a3in
ai4re
a3iv
a2jd
a2jm
aj4me
aj2o
a2k
a3ke
a3ki
a3kl
ak4ni
a3ko
a3kr
a3ku
a3ky
a3ká
a3ké
a3kó
a3kù
a3ký
al4fb
al4kl
al4tz
al3¾í
am4bd
am4kl
am4nu
amo3s
am4¾i
a4nae
a4name
an4dt
ane4sk
aneu4
an4sc
an4sg
an4sl
an4sm
an2sp
an4sv
an4tè
an4¾h
ao4ed
ao4hm
ao4stø
ao4tè
ap4r.
a4pso
ap3t
a4pø.
a2r
a3ra
ar4dw
a3re
a4rer
ar4gl
a3ri
ar4kh
a3ro
a4rox
ar3st
a3ru
ar2va
a3ry
a3rá
a3ró
ar3¹2
ar4¹r
a3rù
arùs3
a3rý
a2s
a3sa
a3se
a3sh
a3sin
as3ná
a3so
as3pi
as4tat
a4stk
as4tm
a4stru.
as3tv
a3su
a3sv
a3sy
a3sá
a3sé
a3sí
a3sù
a2t
a3ta
at4ch
a3te
a3ti
a4tio
at4kl
at3lo
a3to
a3tr
at3re
at3ron
at3rov
a4tru
at4rá
at4th
a3tu
a3tv
a3ty
a3tá
a3té
a3tì
a3tí
a3tó
at1ø
a4tøí.
a3tù
a3tý
a2u
au4gs
a3uj
auj4m
aus3t
a3uè
2av
av3d
av4d.
av3lo
a4vlu
a4vlí
av3t
av4ti
2ay
ay4on
az3k
az3la
az4lé
az3ni
a3zp
a2è
a3èa
a3èe
a3èi
a3èl
aè4má
a3èo
a3èu
a3èá
a3èí
a3èù
a2ò
a3òo
a3òu
aøe4k
a3øí
a4¹pl
a4¹py
a2»
aú3t
2b.
3ba.
ba4br
ba4chr
ba3ka
ba4se
2b1c
b1d
be4ef
be4et
bej4m
be3p
beu4r
be2z3
beze3
b1h
1bi
bi2b3
bis3
bist4
bi4tr
b1j
2bk
3bl.
bl4bl
b2lem
b2les
3blk
b4lán
b2lém
b1m
2bn
1bo
bo4et
bo4jm
bo4ok
bo4tr
bou3s
bo4¹k
b2ral
b2ran
2bri
b4rodit
b4rou
broz4
b2ru
b3ru.
b3rub
b2rán
2b1s2
bs3tr
2b1t
btáh4
bu2c
bu4en
3by.
bys3
by4sm
by4tè
by4zn
b2z
1bá
2b1è
bé4rc
1bì.
bì3ta
1bí
3bín
bí4rc
2bò
b3øa
b3øe.
bøe4s
b1øí
2b¹2
2c.
1ca
cad4l
ca4es
2cc
1ce
cech4
ced4l
celo3
ce4ns
ce4ov
ce4ps
cer4v
ce2u
2ch.
1cha
4chalg
3che
4che.
2chl
ch4ly
ch4mb
2ch3n
2cht
4chte
1chu
ch4u.
1chy
1chá
2chø
1ci
cien4c
cik4l
2ck2
c4ket
ckte4rý
2cl
c3la
c3lé
2cn
1co
co4at
co4mm
co4¾p
c2p
2ct
c2ti
ctis4
ct4la
ct2n
c3tv
c2tì
cuk1
1c2v
cy2
1cá
1cí
cí4pl
2cò
1cù
2d.
1da
da3d
da4j¹
da4kl
da4tr
d1b
d2ba
4dbat.
d2bá
2d1c
dch4l
3dch4n
d1d
dd4ha
1de
de4bre
de3hn
de3jd
dej4mo
de3kl
de3kv
de2na
de2oz
de3sl
de4sm
de4so
de2sp
des4t
de3str
de1x
de4xt
de2z
de3zn
dez3o
de3èt
de4¾p
2d1h
1di
di4gg
4dind
dis3k
di4so
d1j
dj4us
2dk
d3kv
3dl.
d1la
d4lab
d4lak
d3li
1dln
d2lou
d3lou.
d2lu
d3luè
d4lá¾
d1lé
2d1lí
d2lù
d1m
1dmd
dmý¹4
2dn
1do
4dobl
4doboj
dob4rat
do3by
do3bì
do3bý
do1d
4do4dd
4do4dj
dod4n
do3h
doj4m
4dokn
4doly
do3mn
domoh4
do3p
do4pc
dop4n
dor2v
do1s
dos4p
dos4tiv
do3t
do3uk
do3uè
do3z2
doz4n
do3è
4do4èn
doè4t
do4¾p
4dran
d4rap
d1re
d4ren
3drobn
d3ros
d3rou
d3ro¹
dr4sc
d3ru¹
d3ré
d3rý
d4rýv
2d1s2
ds4kù
ds4po
d1t
d3tl
d3tø
1du
dum3ø
du3na
du3p
du4pn
2dur
du3si
du4í.
d2v
d4vac
d3ve
d3vl
d3vr
d3vy
d3vá
d3vì
d3ví
1dy
dy4su
d3zb
d3zd
d3zn
1dá
2d1è
1dé
1dì
3dìj
1dí
2dò
d1øa
døe4k
d4øep
døe4pn
d4øev
d1øí
d2øít
2d¹2
d3¹k
d3¹t
1dù
3dù.
dù3s
1dý
d2¾2
2e.
e1a
ea3dr
e2ar
e1b
eb4er
ebez2
eb4li
e2bø
e4ch.
e3chl.
e4chm
e3cho
e2chr
e3chv
e4ch»
ed4be
ed4kv
ed1l
ed2ma
e3dmn
ed3v
ed4øí
e1e
ee4th
ee3xi
eg4gi
e1ha
e1he
ehno4
eh4nì
e1ho
e1hr
e1hu
e1hy
e1há
e1hý
e1i
eilus3
ej3ag
e3jas
e1je
e3jed
ej3ele
e3jez
ej3in
e3jis
ej1m
ej3mo
e3jmu
ej1o
ej1u
eju3st
ej3v
e2k
e3ka
e3ke
e4kly
e3ko
e3kr
e3ku
e3ky
e3ká
e3ké
e3kó
e3kø
e3kù
e1la
e4lau
el4dv
e1le
e1lo
e1lu
e1ly
el4ze
e1lá
e1lé
e1lí
e1ml
e4mlí
emo3k
e1mr
e1my
e3má
e1mì
e1mí
e3mø
e3mù
e1mý
em3¾e
en4dv
enitos4
en4sc
en4si
ent3r
e1o
eo3by
eoch3r
eod3l
eo4du
e4ole
eo1s
eo2st
eo4tø
eo3z
eo4zb
eo4zd
eo¹e3
epa3t
e2pl
e4pni
ep2no
e4pný
epoè3t
epro4zø
ep4tl
ep4tm
ep4tn
e4ptu
epy3
2er
e1ra
er4a.
e1re
e1ri
e1ro
er3s
er4s.
er4sn
e1ru
e1ry
e1rá
e1ré
e1rù
e1rý
e1s
e4sag
e2sce
e4sin
esi4s
e2sk
es4k.
e4s4kn
es3ku.
es3ky
es3ké
e2sl
e4s3li
e4sly
es2m
e4sp.
es4pe
e2st
e4st.
e4ste
es3ti¾
es4tol
e4strou
es3tán
e1t
e4tki
e4tkr
e4tli
e4tly
et3ri
et3ro
et3rù
et1ø
et4ún
e1u
eu3b
eu3ct
eu3d
eu3k
eu3m
eu4m.
eu3n
eu3p
eu3r
eu4r.
e4ura
eu4ras
eu4rg
eu3s2
eu3t
e4u4t.
eu4tra
eu4ts
eu3v
eu3z
eu3¾
e3vd
eve4¹
e3v2k
e4vsk
evy3
evyjad4
evypá4t
evy4èk
evì4tr
ex4ta
e3xu
ey4or
ey4ov
ezaos3
ez4ap
ez4bo
ez3de
ez3dov
ez3du
ez4dì
e3ze
ez4ed2
ez4ej
ez4el
ez4er
ez4es
ez4ez
ez4e¹
ezis4
ez4it
ez4le
ez4ná
ez4nì
ez4py
ez2t
ez4ác
ez4áh
ez4èe
e3zí
e3zø
ez4øe
e1á
eè4kat
e1èt
eè4te
e4èti
e4ètí
e2ò
e3òo
e3òu
e3òá
e3ón
e1ø
eøe4k
eø4ku
e3øí
e2¹
e3¹e
e3¹i
e4¹ka
e3¹l
e¹4lá
e3¹o
e¹4to
e¹tíh4
e3¹í
eú1
eúmy4
eú3n
eú3p
eú3t
eú3è
e¾í¹4
1f
2f.
fe4in
fene4
fe4ue
fi4em
fi4fl
f2l
f3lí
fló4r
fm4no
2fn
2fr
f4ran
f4ras
3frek
f1ri
2fs
fs4te
2ft
fu4ch
2fé
f2ú
1g
2g.
ga4uè
ge2s
ghou4
3gic
3gin
gi4ím
g4lom
2g1m
2gn
g4noi
g4nos
go1
go4hm
3graf
gu4el
gu4it
gu3m
gu4m.
gus4t
gu3v
2h.
ha4ag
ha4ar
ha4bl
ha4br
ha3dl
ha4dla
ha4ke
has3t
hatos4
ha4yd
h2b
h2c
2hd
he4br
he4id
hej4s
he2s
he2u
he3x
hi4an
hi3er
hi4gh
hi4re
2hk
4hla.
h4led
h3len
2hli
4h3lo.
h3lob
h3lop
h3lov
h3luj
2h1ly
4hlá.
h4lás
h3lí.
4hlík
2hlý
h2m
2h2n
h3ne
h4ned
h3niv
h4noj
3hnìd
3hodin
ho3str
hos4tì
4hove
4hovna
4hovny
4hovná
4hovnì
h2r
hra4p
2h1t
h4tin
h2tì
h4tít
hu4ch
hu3mo
hu4tò
2h2v
hyd1
hy4do
hy4ps
hys3
hy2t3r
hy4zd
h1è
2hò
hø2
hø4by
hý4bl
h2¾
2i.
i1a
ia3d
ia3g2
i4al.
ias4t
ia4tr
i1b
ib2l
i2b1r
i1ch
i4ch¾
i1d
id4ge
id2l
id4lo.
i4dlý
i1em
i1en
i1et
if1r
ig4ne
i1h
i2hl
i3hl.
i4hli
ih3n
ih4na
i3im
i1j
ijed4
ij4me
ij4mi
i2kl
ik3le
ik3lo.
ik3m
ik4ry
i4kve
ik4úø
i1l
il4ba
iliè4n
i4lnu
ilu3
i1m
i4mla
i4mly
i4mun
i2n
i3na
ina3d
in4cm
in4dl
i3ne
3infe
in4gh
in4gp
in4gs
in4gt
i3ni
i3no
i3nu
i3ny
i3ná
i3né
i3nì
i3ní
in4¹p
i3nù
i3ný
i1o
io4sk
i2ps
i1r
iro4s
i1sa
is3c
is4ch
is4k.
is3ka
is3ke
is3ko.
is3kr
is3ku
is3kv
is3ky
i3slav
is3lo
is3lé
is3pl
is3po
is1t
is4tal
is4tat
is4th
ist3v
is3tí
i1sy
i3sá
i1t
it1r
it4rh
it4rp
it4se
it4su
i2tv
i1um
iv3d
i1x
ix4td
i3zp
iz1r
i1á
i1èl
iè3t
iè4tl
iè4to
i2ï
i1é
ié4re.
i1íc
i1ím
i1ó
i1ø
iø4kl
iø4èe
i2¹
i3¹e
i3¹i
i¹3k
i¹4kr
i¹4kv
i3¹o
i¹4to
i3¹u
i3¹á
i3¹í
i2¾
i3¾a
i3¾e
i3¾i
i3¾o
i3¾u
i3¾á
2j.
ja2b2
jac4k
ja4cq
ja3d
ja3g
j3akt
j1b2
jbyst3
2j1c
j2d
j3dob
j3dok
j3dos
j3dr
j3dá
jd4øí
j3dù
jech4
j3ef
j3ex
jez3dí
jg4ra
2j1h
1ji
ji4ch
jih3l
ji4m¾
j4ina
jis3k
jit4ro
ji2zv
j1j
2jk
j3kv
2j1l
j2m
j3ma
j3mi
jmou3d
2jmí
2jn
jne3
j1ob
j1od
jod2ø
j1oh
j1op
j4ora
j1os
jo3sv
j2ov
j3ovl
j1o3z2
2jp
jpor4
jpo4zv
jpøíz4
2j1r
2j1s2
j4sem
j4si.
j4sk.
js4ko
js4ká
j4s4kù
j4s4me
j3sn
j4sou.
j4souc
js4po
j4s4te
2j1t
j3tl
ju4an
ju3na
ju3p
j1us
ju3sp
ju3t
ju4t.
ju3v
ju4xt
ju3z
j1u¾
ju3¾i
2jv2
j3vd
j3vn
2jz
j3zb
j3zd
j3zk
j3zn
j3zp
jád2r
2j1è
2jï
1jí
j3¹t
j¹4ti
j3¹»
2jú1
jú3n
jú3è
jú3¾
2j¾
1k
2k.
ka4bl
ka4ch
ka3dl
3kaj
ka3ka
3kami
3kanì
ka2p3l
ka2p3r
ka2ps
ka4pv
ka2pø
kas3t
kast3r
3kat
ka4uè
3kav
3kaè
3kaø
ka¹3l
ka4¹p
2k1c
k2d
k2e
ke4bl
ke3jo
ke4pr
ke4ps
3ket
2kf
2kk
k2l
3kl.
4k3la.
k3lej
4k3li.
k4lib
k3lic
4klièka
4klo.
k3los
2k3ly
k3lá.
k3lé
k3ló
k3lý
2k2m
k3mì
2kn
kna4s
ko3by
3kof
ko4jm
ko2pø
ko4sk
ko2t3v
kous3k
3kov
ko3zá
4kroa
k3rob
k3rof
kr2s
kr4ú.
2ks
2k1t
kt2r
kuch4
ku4fø
ku4hr
3kuj
ku3se
ku3si
ku3su
ku4th
ku3v
2k2v
k4vrò
3kyn
ky2pr
kyp3ø
ky4zn
3kác
ká4pl
3kár
3káø
2kè
k2ò
k2ø2
k3øej
k¹4ti
3kù.
2l.
1la.
la4br
lab4s
la3ka
la4nq
la4ps
4la3si
la4v¹
la4y.
la2zm
2l1b
2l1c
2l1d
ld4ne
le4ad
le4au
lech3t
leh3n
le2i
1lej
le3jo
4lej¹k
1lel
4lench
lepa3d
lepo4s
le4pr
le4ps
le4sc
le4sm
le4sv
let4li
let3m
le2tr
le4tè
le4uk
le4vh
le4vk
le3xi
lez3n
2lf
2lg
2lh
3lhan
1li
li4az
li4bl
li4bv
li4dm
lind4
3lio
li4tò
li4vr
2li¾
2lj
2lk
l4kat
l2kl
lk4nu
2ll
2l1m
2ln
l4nul
lo3br
lo4id
lo4is
1los
lo3sp
lo3stø
lo3sv
lo2tr
lo4tø
lo4u.
lo3z
loz4d
lo4¹k
2lp
l2pì
2l1s2
l4sla
ls3n
lst4n
l4stí
2l1t
lt4ra
lt4ru
lt4ry
lu4id
lu4j.
lu4k.
lu4lk
lu4m.
lu4mn
lu3pr
lu3va
lu3vl
lu3vy
lu3ví
2lv
2lz
1lá.
lá4j¹
lá4v¹
2l1è
1lé.
1lík
lí4pl
lí4zn
1líø
2lò
2l¹2
l3¹t
l4¹tý
1lù
1lý
lý2t
2l2¾
2m.
1ma
maj4s
ma4kl
ma4kr
4mald
mas3k
mat3r
ma4tra
ma4v¹
maz3l
2m1b
2m1c
2m1d2
m2dl
1me
3me.
me4go
me4is
met3re
me3x
mezi3s
2mf
mh4le
1mi
mid3l
mik3r
mi4xt
2mk2
3m2kl
mk4la
mk4li
m2l
4mla.
2mle
ml3h
ml4h.
2mli
ml4sc
ml4sk
4mlu.
2mn
m3na
mna4s
m4noh
m3nos
m4noz
3mno¾
m3ná
m3né
m4néz
m3nìj
m3ný
1mo
mod3r
mo2hl
mo2k
mo2s
mo4s.
mot3ø
4mout
moza4
mo3zø
moú3
2mp
m4plo
mpo4s
m2ps
mp4se
mp2t
mr2s
2m1s2
m4stl
2m1t
1mu
mu4fl
mu3n
mu4n.
mu4nd
mu4nn
mu4ns
mu4n¹
2mu¹
2mv
mys3lo
my4¹k
2mz
3má.
málo3
má2s
2mè
m2èe
mí1c
mí4rò
2m2¹
m¹4èi
m¹3»
m¹4»an.
3mù.
3mý.
m2¾
1n
2n.
3na.
na3ch
na4do
na4em
na3h
na4h.
na3jd
na3ka
nam4ne
na3p2
na3s2
na4s.
nat2
na3tl
na3tø
na3z
naz4k
na4z¹
na4è.
na3¹
na¾4n
2nb
2n1c
n4chc
2n1d
nd4hi
ndo4t
nd2re
nd4ri
nd4øí
ne1d
ne4gl
ne1h
ne3h4n
ne2j
nej3t
nej3u
ne3kl
ne4kro
ne3kv
ne4m.
ne3p
ne3s2
ne4s.
nes4le
ne4ss
4nesti
ne3tl
net4r
ne3ud
ne3v2
ne4v.
ne3z
nez4n
ne3¹k
ne3¹»
2nf
n3fr
2ng
ng1l
ng4la
ng4le
ng4lí
n4gro
ng4vi
nik4t
ni4mr
ni4m¾
3nio
3nisk
2nitø
n1j
2nk
2n1l
2nn
no3b2
no4bs
no3hn
no4hs
no4ir
no4m¾
no4sky
no3sm
no3str
not4r
no3z
no4zd
no4¹k
2no¾
2n1s2
n2sa
ns3ak
ns4ko
n4soc
ns3po
nst4ra
2n1t
nte4r3a
nt4lem
nt4r.
nt3ru
nt3rá
2nub
nu4gg
3ny.
2nz
3nák
ná3s2
ná4s.
2n1è
2nï
2nív
2ní¾
2nó
2n¹2
n3¹t
n¹4»o
nù2
2n¾
2o.
o1a
oang4
o1ba
o1be
obe3j
obe3s
obe3z
ob1l
ob1r
ob4rò
o1bu
obys4
ob3z
o3bé
ob3øez
o1c
o4chl
o2chr
oc4ke
oc4ko
o4ct.
oct3n
ocy3
oc4ún
od3b
odej4m
ode3p
ode3s
od1l
o4doc
odos4
odo4tk
od3ra
od4ran
od3rù
o3dr¾
od3v
od1ø
o1e2
oe3g
oe3ti
o2fl
ofrek4
og2
o3gn
o1h
oh4ne
o1i
oi4ce
o4int
o1j
o4jar
oje4dl
o4jmi
o4jmov
o4jmu
o4jmù
oj2o
o4juz
2oka
ok2te
o1l
ol4gl
ol4to
o1m
om4kl
om2n
o2n
o3na
ona4s
o3ne
o3ni
o3no
ont4ra
o3nu
o3ny
o3ná
onáø4ka
o3nì
o3ní
o3nù
o3ný
o1o
oo4hø
oote2
opoè3t
opro4s
o2ps
o4ptu
opá4t
o4pø.
opøej4
opøe4jm
o1ra
o4rae
or4dm
o1re
o1ri
o1ro
or3st
o1ru
or4vá
o1ry
o1rá
o3ré
o1rù
orùs3
o3rý
o1sa
o4sai
ose4s
osi4d
o1sk
o4s3ke
o4sku
osk3v
o4ská
o4ský
o1sl
os4la
os4li
os4lý
os3mo
os4mu
o4st.
o4stg
o4stm
os4tor
os3trù
o4sté
o4st¹
o4stý
o1sy
o1t
ot4kl
o4tlý
oto3s
ot3ro
ot3ví
o3tí
o3tø
ot3øi
o2u
ou3bì
ou3dì
ou4fl
ou4il
ou4is
ou4k.
ou3ka
o4ukl
ou3kr
ou3ká
ou3m
oup3n
oupo4
ou4s.
ou3sa
ou3se
ou4sk
ou3sm
ou4tv
ou3v
ou4vl
ou4vn
ouz3d
o4uèk
ou3¾i
ovi4dla
o4vsk
ovy2p
o2v¹t
o1x
o2z
o3za
oz1b
oz4d.
oz3dá
oz3dì
oz3dí
o3ze
oze3d2
ozer4
oz1h
o3zi
oz3j
oz3k
oz4ko
oz1l
oz3m
o4zn.
o3zo
oz3p
oz4py
oz4pì
oz4pí
oz3ro
oz3ru
oz3rù
oz3t
o3zu
o4zut
oz3vr
oz3vá
o3zí
o3zù
ozù4s
o1è
oè2k
oè4ka
o2ò
o3òa
o3òo
o1ø
oøi2s
o3¹k
o4¹ku
o4¹ky
o3¹l
o¹4lá
o¹4mo
o¹4ti
o¹4»u
o3¾l
o¾4mo
1p
2p.
pa4ed
pa4es
pa4kl
pa3si
pa4t.
pat4ri
2p1c
pe4al
pede4
pe4ig
pe4np
peri3
pes3t3
pe4tra
3peè
pi4kr
pi4pl
2pk
p2kl
p2l
3pl.
4p3la.
pl3h
pl4h.
4p3li.
4plo.
2pn
p2nu
po1b2
po3c2
3pod
podbì4h
pod4nes
po3dru
po3drá
po3h
poly3
po3m2
po4mp
po4ol
po3p
po4p.
po4pm
po1s2
pos4p
post4r
po3t2
po4t.
po4tn
po3uk
po3uè
po3u¾
3po3v
po3z2
po4zd
poè2
po3èk
poè3te
po3øí
po4¹v
2pp
4pra.
pra3st
pr2c
pro1
prob2
pro3p
pro3t4
pro3z
pr2s
4prán
prù3
pse4s
2p1sk
p4sut
2pt
p4tej
p4ter
p4tev
pt4ri
p3tu
p4tá.
pu4dl
pu4tr
pyt3l
pá1
pá2c
pád3l
pá4nv
pá4sl
2pè
pé4rh
2pø.
pøe3h
pøe3j
pøe3t4
pøe3z
pøe3è2
pøi3
pøih4
2p¹
p¹4ti
2p»
qu2
2r.
1ra.
ra4br
ra4em
ra4es
ra4ff
ra4hl
ra4hm
ra4jg
ra4j¹
2rak
ra4nh
ra3si
rast4r
ra4vv
ra4wl
ra4y.
ra4yo
ra4ïm
4ra¾i
r1b
r2bl
r1c
rca3
r3cha
r3cho
rc4ki
r1d
r4dla
rdo2s
re4ad
re4au
red4r
re4et
re3kl
re3kvi
re4mr
re2sb
res3l
retis4
ret4r
re4um
r1ha
r3hl.
rh3n
r1ho
r3hu
r1há
ri4bb
1ric
ric4ku
ri4dg
ri4dr
ri4fl
ri4gh
ri4zm
2rk
r2kl
r1l
2r1m
r4mio
2rn
rna4v¹
rn4dr
ro4ad
ro3by
rod2l
ro3d4r
3rofy
ro3h
ro4h.
ro4jb
ro4k¹
rom3n
romy4s
ropát4
ro2sb
ro4skv
ro4sky
ro3sv
ro3ti
ro3tl
ro4tè
ro3vd
rovì4t
3rový
roz3d
roz3n
ro4zo
roz3v
ro3zá
ro4èp
rpa3d
2rr
rr4ha
rr4ho
2r1s
r2st
r4stu
rs3tvì
rs3tvý
2r1t
r2th
r4trá
rt4sm
rtu3
r2t3v
rt4zu
1ru.
ru3se
ru3si
rus3k
ru3¾i
3rvaní
r1x
1ry.
rych3
ryd2
rys3ky
rys3t
ry4zk
ry4zn
ry4í.
ry4¹k
2rz
rz3d
rz3l
rád4l
rá4d¾
1rák
rá3ri
1ráø
r1è
4rèitý.
rè3t
3ré.
2ró
2r¹
r¹4ní
rù4m.
rùs3ta
rù4v.
3rý.
rý4zn
2s.
sa4pf
sa4pr
sas3k
s2b2
s2c
s3ca
s3ce.
sch2
sch4l
sch4n
3schop
s3ci
sci4e
s3cí
s2d
1se
se4au
se3h
se4ig
se4il
sej4m
se4ku
3sel
se3lh
3sem
ser4va
se3s2
ses4k
se4ss
se4stra
se4stru
se4stø
set2
se3tk
se3tø
se4ur
se3z
se3èt
2sf
s3fo
3sfé
s3fú
1si
3sic
3sif
si4fl
sig4no
3sik
si3ste
3sit
s2j
s3ju
s2k
4skac
s4kak
4skam
s4kok
2skon
skos4
4skot
sk4ra
sk4ru
sk4ry
4skve
sk4vo
s3kán
s3kù
3sl.
4s3la.
s4lav
s3le.
s4led
s3lem
s3len
s3let
s4lib
s4lièi
3sln
4s3lo.
s2ly
s3ly.
s1lí
s2ma
s4mek
s2mo
2sn
s2na
s3nat
s2ne
s3ne.
sn4tl
s2ná
s3ná.
s4níd
1so
sob4l
so3br
so4sk
so4tv
sou3h
sou3s
souz4
so4¹k
s2p
s4pol
spro4s
1sr
2ss
ss4sr
2st.
4sta.
s3taj
s2tan
st4at
4stec
s4tep
st4er
s4tero
s4tich
2stil
s4tink
4stit.
4stiè
st3lo
2stn
4sto.
s4tona
4stou.
4str.
4stram
s4trik
4strn
4strác
4stupni
s2tv
st4ve
3ství
4sty.
s4tyl
3sty¹
s2tá
4stá.
s3táø
4stì.
s4tìd
3stìh
s2tìr
s2tì¾
s1tí
2stí.
s3tøej
1su
su4ba
su4bo
suma4
su3ve
s2v
sy3c
sych3r
sy4nes
sá2d
3sáh
sá2kl
2s2è
s3èi
1sé
1sí
2sò
2s»
s3»o
1sù
s2¾
2t.
1ta.
ta2bl
tac4tvo
t2a3d
1taj
ta4jf
ta4jg
4talt
4tand
3tanì
t1ao
2tark
tast4
ta3str
ta4èk
2t1b
2t1c
1te
3te.
te4ak
te4fl
te4in
4teném
teob4
tep3l
ters4
tes3ta
te4tr
te4uc
te4ur
te4ut
2tf
2tg
1ti
ti4gr
2tih
ti3kl
tin4g
ti4pl
ti3sl
tis4tr
ti4tr
2titu
tiz4r
4tizí
tiú3
2ti¾
2tk2
t4kal
4t2kan
t4kat
t2kl
tk4la
tk4li
4tknì
t2ká
2tl
3tl.
4tla.
t1le
tles3
3tlm
t3lo.
t4lou
tlu3
tlu4s
t1ly
t1lé
2tm
t2ma
2tn
t3ní
1to
to4as
to3b
tob4l
to3dr
to4hm
to4ir
2toj
tol4s
to4ol
4top.
4topt
4topu
2torn
2toup
2tp
t3rant
t4rea
t4ref
tre4t
4tric.
trip4
t4rit
t4rog
t3rol
tro4sk
t4rou
4trouh
4troò.
4trun
t4rus
4t4ru¾
t3ráln
4trá¹
2trè
t3rùm
t3rùv
2trý
2t1s
ts4ko
ts2t
2t1t
tt4ch
tt4ri
1tu.
tu4ff
1tuj
tu4lk
2tup
tu4r.
tu3ry
tu4s.
tu4».
tu3¾i
t2v
2tve
2t3vi
t4vinn
t4vi¹
t4výc
1ty.
ty4gø
ty2la
ty4øe
ty4øh
ty4øj
ty4øo
ty4ør
ty4øú
3tá.
tá4fl
t2è
t3èi
2tèí
1té
té2bl
3tém
1tì
tì3d4l
2tìh
2tìnn
2tìp
1tíc
4tíc.
4tíce
1tím
2tín
2tír
2tø
t4øeb
tøeh3n
t2øel
t2øic
t3øil
tø4ti
t1øu
t2øá
3tøáb
tøí4s
2t¹
t3¹t
t¹4ti
1tù
1tý.
1tým
1týø
3tý¹
u1
2u.
u2at
u2b
u3ba
u3be
u3bi
u3bo
ubs4t
u3bu
u3bá
u3bí.
u3bù
uc4tí
2u2d
u3de
u3di
u3do
u3dru
u3du
u3dy
u3dí
ue4fa
2uf
u2hl
uh3lá
uh3no
u2in
u2jm
u2k
u3ka.
uk4aj
uk4al
uk4at
u3ke
uk3la
uk3le
u3ko
u3ku
u3ky
uk4á.
u3kù
ul4fa
ul1h
ul4pí
u2m
u3ma
u3me
u3mi
um4pl
um4ru
u3mu
u3má
3umø
u2n
un4dl
u3ne
u3no
u3nu
u3nì
u3ní
u3nù
un4¾r
u2p
u3pa
u3pe
upe2r3
u3pi
u3pln
u3pu
u3py
u3pá
u3pì
u3pí
u3pù
u2r
u3ra
u3re
u3ri
2u3ro
u3ru
u3ry.
u3rá
1urè
u3rù
u2s
us3ky
us3ká
us3ké
us3ký
us1l
us2lo
u3so
u4ste
u4sty
u4sté
u4stì
u3stø
u4st¹
u4stý
u3su.
u3sy
u3sá
u3sí
u3sù
u4tro
u4trá
u2v
u3vi
u3vu
u2z
u3ze
u3zi
uz1l
u3zo
u3zu
u3zí
u2è
u3èa
u3èe
u3èi
u3èo
uè3t
u3èu
u3èá
u3èí
u2ï
u2ò
u2¹
u3¹e
u3¹i
u¹4kl
u3¹o
u¹3tí
u3¹u
u3¹á
u3¹í
u2¾
u3¾e
u3¾o
u3¾u
u3¾á
u3¾í
1v
2v.
va3dl
va4j»
va4kl
2v1b
2v1c
v2ch
2v2d
v4dal
v3di
v4dìk
v4dìè
ve3dle
ve3jd
3ven
ve2p
ve3ps
vep3ø
ves3l
ve4sm
ves4p
ve3sta
ve3t4ø
ve2z3m
vi4ch
vide2
vi4dr
vi4et
vi4kr
vi2tr
2vk
v2kr
v2l
2v3la.
4vle.
4vlem
2vlo
2vm
2vn
v4nad
vo3b
vo4ic
vo4ja
vo4jb
vo4jd
vo4jj
vo4jm
vo4jø
vo2s
vo4tø
vou3
vous2
v2p
vr2c
vr2dl
4vrny
v1ro
vr4st
vrst3v
vrs4tvì
2vs2
v1sk
v3stv
2v2t
vy3c
vy3d2
vy4dra
vyp2
vy3s2
vy4sn
vys4t
vy3t
vy3è
vyè4k
vy¹2
vy4¹.
vy4¹m
vy4¹¹
vy4¾l
v2z2
vz4no
vz4né
vz4nì
vz4ní
vá3ri
2v2è
v3èá
v3èí
v4èír
vì4cm
vì3t4a
více3
ví4hat
3vín
2vò
2vøí
v3øín
v2¹2
v¹e3s
v3¹tí.
3výs
vý3t
3vý3z
v2¾2
wa4fd
3war
wa4re
we2
2x.
xand4
2xf
xisk4
2xn
3xov
x1t
xt4ra
xy4sm
y1
y2a
y2bl
yb3ri
y2ch
y4chr
y2d1l
yd4lá
y2dr
yd4y.
y2e
y2gr
y3hn
yh4ne
yj4ma
yj4me
y2kl
yk3la
y3klop
yk4ly
ymané4
ym4kl
yna4s
y3ni
ype4r
yp4si
yp4tá
y2pø
yr2v
y2s
y3sa
y3se
y3si
ys3lu
y3sm
y3so
y3sp
ys2t
ys3te
yst4r
y3su
y3sv
y3sy
y3sá
y3sé
y3sí
yt4me
yu3¾
y3vs
yvì4t
y3zb
y3zd
y3zk
y3zn
yz4nì
yz4ní
y3zp
yz4po
yè2k
y2ò
yø3b
yøk4n
yø4èe
y3øí
y2¹
y3¹e
y3¹i
y3¹k
y¹1l
y3¹o
y3¹p
y3¹u
y3¹í
y¾2
y3¾d
1z
2z.
zab2l
za4bs
za4dk
za3dl
za4dn
za3h
za3i
za3j
za4jk
za3k
za4kt
zal4k
zam4n
za3p2
za3s2
zat2
za3tl
zat4r
za4ut
za3z
zaz4n
za4z¹
za4è.
za3¹
za¹4k
za4¹s
2zb
zban4
z2by
zbys4
2z1c
2z2d
z3di
zdnì4ní
z4doba
z4dobný
zd4re
zd4ví
z2e
ze3h
ze3p2
4zerot
ze3s2
zes4p
zet2
zev2
ze3vn
ze3z
ze4z.
2z2f
z1há
z4ine
z2j
z3jí
2z2k
z3ka.
z3ky
z3ké
z3kù
z3ký
2zl
3zl.
zlhos4
zlik3
z3ly.
z2m2
2zme
z3mn
z3my
z4mìn
2z2n
3znak
z4nal
z3ne.
z3nic
z3no
z3nu
z3ny
z3né
z3nì
z4nìl
z3ní
z4nít
z4nív
z3ný
zo4tr
zo4¹k
2z2p
z3pt
z4pát
3zrak
2z1s2
2zt
ztros3
z4trá
z3tø
3zu.
zu3mo
zu3mì
zu3mí
zu3¹
z2v
zva4d
z3vaø
z3vi
zvik4
zv4nì
z3vod
z3voj
z4von
zv4ro
z4ván
z4vìs
z3víj
3zy.
2zz
zá1
záh2
zá4kl.
3záp
zá3s2
zá3z
zá¹2
2zè
z3èl
2zò
z2ø
zøej3
z3øez
z3øe¹
2z¹2
z3¹k
z¹4ka
z3¹t
2z2ú1
zú3è
zú3¾
zù3s
á1b
á2bl
áb4ry
á4bø.
á3cho
ác3ti3
á1d
á2dl
ádo4s
ádos4ti
ád1ø
á1ha
á3he
áh1l
á3hl.
áh3n
á1ho
á1hr
á1há
á1j
á4jmu
áj4mù
á4kli
ák4ni
á1la
á1le
á1lo
á1lu
á1ly
á3lé
á1lí
á3my
á3mé
á1mì
á3mí
á3mý
áne4v
á1ra
á1re
ár2m
á1ro
á1ru
á3rù
á1s
á2sc
á2s3k
ás4k.
ás4kl
ás4kn
á2sla
ás4ly
á2sm
ás4po
á2st
át3k
át1r
á1tu
á1ty
á1tí
á3tý
áv4si
áv4sí
áz3k
áz3ni
ázni4c
áz4vi
á2ò
á1ø
áø4ke
áø4kù
á2¹
á3¹e
á3¹í
2è.
1èa
èa4br
2èb
2è1c
1èe
3èe.
èe1c
èes3k
1èi
2èk
è3ka.
è3ko
è3ku
è3ky
2è1m
2èn
è2ne
1èo
è2p
2ès
è1sk
ès4la
ès4sr
2è2t
è4tené.
è4tený
èt4la
è4tový.
3ètv
4ètìn
è3tí
1èu
1èá
1èí
èís3l
1èù
2ï.
1ïa
1ïo
ïs4te
2ï1t
3ïuj
é1
é2d
é3di
é3do
é2f
é3fo
éf1r
é2kl
é2l
é2m
é3ma
é3me
é3mi
é3mo
é3mu
é3mù
4ére.
é2s
é2t
é3ta
é3to
é3tá
é2¹
é2¾
ì1c
ìd3r
ì3ha
ì3he
ì3hl.
ìh3lo
ìh3n
ì1ho
ì3hu
ì3hù
ì3ja
ì1je
ì1jo
ì3jù
ì4klé
ì3k2t
ì1l
ì1ra
ìra3d
ì1re
ì1ro
ìr3s
ìrs4t
ì1ru
ì1ry
ì1rù
ìs3k
ìs3n
ìt1a3
ìt4ac
ìt1l
ì1tr
ìt3ra
ì4traj
ìt3v
ì1tí
ìt3øí
ì2v
ì3va
ì3ve
ì3vl
ì3vo
ì3vu
ì3vá
ìv3è
ì2z
ì3ze
ì3zi
ìz3n
ì3zo
ì3zí
ì1ø
ì2¹
ì3¹e
ì3¹i
ì3¹o
ì3¹u
ì3¹á
ì3¹í
ì¹3»
ì¹4»s
ì2»
ì3»o
ì2¾
ì3¾e
ì3¾i
ì3¾o
ì3¾u
ì3¾í
í1b
íb3ø
í3cho
ích4t
íd1l
í1h
í2hl
íh3n
í1j
íjed4
íj4mù
í2kr
í1l
í1má
í3mé
í1mì
í1r
í1sa
í2s3k
ís4kl
ís4kn
ís4l.
ís3le
ís4ln
ísáh2
í1t
ít3k
í3t3øe
íz3da
íz3de
íz3k
í3zna
í3z3ni
í3znìn
í2ò
í1ø
í2¹
í3¹e
í3¹i
í3¹o
í3¹í
1ò
2ò.
2òa
òa3d
2òk
2òm
3òov
ò1s
2ò1t
ó1
ó2z
ó3za
ó3zi
ó3zo
ó3zy
2ø.
øa4pl
øa4ïm
2ø2b
2øc
2ød
øe3ch
øe4dob
øe1h
øe3jd
øe3kl
øe3kv
øe4køí
øeo4r
øe3p2
øe4p.
øe4pk
øe4pè
øer4v
2øes
øe3ska
øe3sko
øe2sp
øes3po
øe4sr
øe3sta
øe3stu
øe3stá
øe3stø
øe3tl
øet4ø
øe3zd
øe3zk
4øezl
øe3èt
øi1
øia3
øi3h
øi4h.
øi4hn
øi4jï
øi4l.
øi4lb
øil2n
4øine
øis2
3øi4t.
øi4v.
øi4vk
øi4vn
øi3z
øiè4t
øi3ø
øi4¹.
2øk
ø2kl
øk4la
øk4li
øk4ly
øk4no
2ø1l
2ø1m
2øn
1øo
2øou
2ø2p
2ø1s
øs4to
2ø1t
ø2v
2øz
øá4pl
øá2sl
2ø1è
2øíd
øí4kø
øí1s
2ø¹
ø3¹t
ø¹4ti
1¹
2¹.
¹ab3
¹a4vl
2¹1c
¹ej4d
¹ep3t
¹i4mr
2¹2k
¹3ka
¹3ke
¹3k3li
4¹3kou
4¹kov
3¹kr
¹k4ro
¹3ku.
¹3ky
2¹l
¹2la
¹2li
¹3liv
¹2lo
¹lá2
¹2lé
¹2lý
2¹1m
¹mi4d
2¹n
¹2p
2¹1s
2¹t
¹4tip
¹t4ka
¹t4kl
¹4tìk
¹2tìs
¹4tìv
¹4típ
¹2v
¹í3d
¹2ò
¹3¹í
2¹2»
¹3»o
¹3»u
¹3»á
1»
2».
3»al
2»k
2»m
2»t
»áè4k
1ú
ú2c2
ú2d
új4ma
ú2k
ú2l
ú2n
ú2p
ú2t
út4ko
ú2v
ú2z
úz3k
ú2è
3úèe
úøe4z
ú¹4ti
ú2¾
ù1b
ù1c
ù1hl
ù3jd
ù4jmový
ù1le
ù1my
ù1mì
ù1ra
ùr4va
ùr4vy
ù1s2
ù2st
ùs3te
ùs3tán
ùt2
ù3tkl
ù2v
ù3va
ù3vo
ù3vì
ù2z
ù3zo
ù2¾
ù3¾e
ù3¾i
ù3¾o
ý1b
ý3cho
ý1d
ýd4la
ý1h
ý1j
ý1l
ý1ml
ý1mì
ý2n
ý3no
ýpo3è4
ý1r
ý1s2
ý2sk
ý1t
ýt4ku
ýt4ky
ý1u
ý4vli
ý3zk
ý3zn
ý4zvu
ýè4nì
ý1ø
ý¹3l
1¾
2¾.
¾a3d
¾a4tv
3¾aè
2¾1b
2¾1c
2¾1d
¾e2b3
¾eh3n
¾e4ml
¾e4zg
¾i4dl
¾i4jm
3¾il
¾i2vl
2¾k
¾k4ni
2¾l
¾4lic
3¾lo
2¾1m
2¾n
¾on2
2¾1s2
2¾1t
¾2v
¾á4br
¾á4nr
2¾ï
¾í4zn
2¾ò
2¾¹
¾¹4ti
¾¹4tì
}

% Local Variables:
% coding: latin-2
% End:
%
% End of file `hyphen.cs'.
